@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-04-17'; # DATE
 our $DIST = 'Sah-Schemas-Firefox'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 sub meta {
     +{
@@ -29,7 +29,7 @@ sub filter {
         "do { ",
         "  my \$tmp = $dt; ",
         "  my \$dir = Firefox::Util::Profile::get_firefox_profile_dir(\$tmp); ",
-        "  if (!defined \$dir) { [\"No such Firefox profile\", \$tmp] } else { [undef, \$tmp] } ",
+        "  if (!defined \$dir) { [\"No such Firefox profile '\$tmp'\", \$tmp] } else { [undef, \$tmp] } ",
         "}",
     );
 
@@ -51,7 +51,7 @@ Data::Sah::Filter::perl::Firefox::check_profile_name_exists
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Filter::perl::Firefox::check_profile_name_exists (from Perl distribution Sah-Schemas-Firefox), released on 2023-04-17.
+This document describes version 0.005 of Data::Sah::Filter::perl::Firefox::check_profile_name_exists (from Perl distribution Sah-Schemas-Firefox), released on 2023-04-17.
 
 =for Pod::Coverage ^(meta|filter)$
 
